==> zio-aws-datazone_2.13-7.21.15.9-sources.jar: zio/aws/datazone/model/ListSubscriptionGrantsResponse.scala <==
package zio.aws.datazone.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.datazone.model.primitives.PaginationToken
import scala.jdk.CollectionConverters._
final case class ListSubscriptionGrantsResponse(
    items: Iterable[zio.aws.datazone.model.SubscriptionGrantSummary],
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datazone.model.ListSubscriptionGrantsResponse = {
    import ListSubscriptionGrantsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datazone.model.ListSubscriptionGrantsResponse
      .builder()
      .items(items.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.datazone.model.ListSubscriptionGrantsResponse.ReadOnly =
    zio.aws.datazone.model.ListSubscriptionGrantsResponse.wrap(buildAwsValue())
}
object ListSubscriptionGrantsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datazone.model.ListSubscriptionGrantsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datazone.model.ListSubscriptionGrantsResponse =
      zio.aws.datazone.model.ListSubscriptionGrantsResponse(
        items.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def items: List[zio.aws.datazone.model.SubscriptionGrantSummary.ReadOnly]
    def nextToken: Optional[PaginationToken]
    def getItems: ZIO[Any, Nothing, List[
      zio.aws.datazone.model.SubscriptionGrantSummary.ReadOnly
    ]] = ZIO.succeed(items)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datazone.model.ListSubscriptionGrantsResponse
  ) extends zio.aws.datazone.model.ListSubscriptionGrantsResponse.ReadOnly {
    override val items
        : List[zio.aws.datazone.model.SubscriptionGrantSummary.ReadOnly] = impl
      .items()
      .asScala
      .map { item =>
        zio.aws.datazone.model.SubscriptionGrantSummary.wrap(item)
      }
      .toList
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.datazone.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datazone.model.ListSubscriptionGrantsResponse
  ): zio.aws.datazone.model.ListSubscriptionGrantsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-datazone_3-7.21.15.10-sources.jar: zio/aws/datazone/model/ListSubscriptionGrantsResponse.scala <==
package zio.aws.datazone.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.datazone.model.primitives.PaginationToken
import scala.jdk.CollectionConverters.*
final case class ListSubscriptionGrantsResponse(
    items: Iterable[zio.aws.datazone.model.SubscriptionGrantSummary],
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datazone.model.ListSubscriptionGrantsResponse = {
    import ListSubscriptionGrantsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datazone.model.ListSubscriptionGrantsResponse
      .builder()
      .items(items.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.datazone.model.ListSubscriptionGrantsResponse.ReadOnly =
    zio.aws.datazone.model.ListSubscriptionGrantsResponse.wrap(buildAwsValue())
}
object ListSubscriptionGrantsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datazone.model.ListSubscriptionGrantsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datazone.model.ListSubscriptionGrantsResponse =
      zio.aws.datazone.model.ListSubscriptionGrantsResponse(
        items.map { item =>
          item.asEditable
        },
        nextToken.map(value => value)
      )
    def items: List[zio.aws.datazone.model.SubscriptionGrantSummary.ReadOnly]
    def nextToken: Optional[PaginationToken]
    def getItems: ZIO[Any, Nothing, List[
      zio.aws.datazone.model.SubscriptionGrantSummary.ReadOnly
    ]] = ZIO.succeed(items)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datazone.model.ListSubscriptionGrantsResponse
  ) extends zio.aws.datazone.model.ListSubscriptionGrantsResponse.ReadOnly {
    override val items
        : List[zio.aws.datazone.model.SubscriptionGrantSummary.ReadOnly] = impl
      .items()
      .asScala
      .map { item =>
        zio.aws.datazone.model.SubscriptionGrantSummary.wrap(item)
      }
      .toList
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.datazone.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datazone.model.ListSubscriptionGrantsResponse
  ): zio.aws.datazone.model.ListSubscriptionGrantsResponse.ReadOnly =
    new Wrapper(impl)
}
